pub struct BridgeRef {
pub frontier: String,
pub finding_id: String,
pub assertion_text: String,
pub confidence: f64,
pub direction: Option<String>,
}Fields
frontier: StringHuman label of the frontier this finding belongs to.
finding_id: Stringvf_<id>.
assertion_text: StringSnapshot of the assertion text at derivation time. Lets the bridge survive a frontier rewrite (the bridge captures what was true when it was derived).
confidence: f64direction: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BridgeRef
impl<'de> Deserialize<'de> for BridgeRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for BridgeRef