pub fn init()Expand description
Initialize styling. Call once near the CLI entry point.
Disables all ANSI output when stdout is not a terminal or NO_COLOR is set.
Safe to call multiple times; only the first call takes effect.
pub fn init()Initialize styling. Call once near the CLI entry point.
Disables all ANSI output when stdout is not a terminal or NO_COLOR is set.
Safe to call multiple times; only the first call takes effect.