pub fn normalize_findings(bundles: &mut [FindingBundle]) -> (usize, usize)Expand description
Normalize all findings: fix entity types and names, deduplicate entities within findings.
pub fn normalize_findings(bundles: &mut [FindingBundle]) -> (usize, usize)Normalize all findings: fix entity types and names, deduplicate entities within findings.