pub fn plan_source(source_path: &Path) -> Result<NormalizeReport, String>Expand description
Plan normalization for a source path without writing changes.
pub fn plan_source(source_path: &Path) -> Result<NormalizeReport, String>Plan normalization for a source path without writing changes.