Module tensions

Module tensions 

Unresolved contradiction analysis — “Where does science disagree with itself?”

Finds all contradicts link pairs, scores them by tension (high confidence on both sides = maximum tension), and checks whether a superseding finding has resolved the disagreement.

Structs

Tension
A pair of contradicting findings with a tension score.
TensionSide
One side of a contradiction.

Functions

analyze
Run the tensions analysis.
print_tensions
Print the tensions report to stdout with colored formatting.