pub fn plan_project_changes(frontier: &Project) -> Vec<NormalizeChange>Expand description
Build a deterministic repair plan for a loaded frontier, including content address and internal link updates implied by entity normalization.
pub fn plan_project_changes(frontier: &Project) -> Vec<NormalizeChange>Build a deterministic repair plan for a loaded frontier, including content address and internal link updates implied by entity normalization.